embassy-stm32

Crates

git

Versions

stm32c092rc

Flavors

Mms2

Enum Mms2 

#[repr(u8)]
pub enum Mms2 {
Show 16 variants Reset = 0, Enable = 1, Update = 2, ComparePulse = 3, CompareOc1 = 4, CompareOc2 = 5, CompareOc3 = 6, CompareOc4 = 7, CompareOc5 = 8, CompareOc6 = 9, ComparePulseOc4 = 10, ComparePulseOc6 = 11, ComparePulseOc4OrOc6Rising = 12, ComparePulseOc4RisingOrOc6Falling = 13, ComparePulseOc5OrOc6Rising = 14, ComparePulseOc5RisingOrOc6Falling = 15,
}

Variants



Reset = 0

The UG bit from the TIMx_EGR register is used as TRGO2



Enable = 1

The counter enable signal, CNT_EN, is used as TRGO2



Update = 2

The update event is selected as TRGO2



ComparePulse = 3

TRGO2 send a positive pulse when the CC1IF flag it to be set, as soon as a capture or a compare match occurred



CompareOc1 = 4

OC1REF signal is used as TRGO2



CompareOc2 = 5

OC2REF signal is used as TRGO2



CompareOc3 = 6

OC3REF signal is used as TRGO2



CompareOc4 = 7

OC4REF signal is used as TRGO2



CompareOc5 = 8

OC5REF signal is used as TRGO2



CompareOc6 = 9

OC6REF signal is used as TRGO2



ComparePulseOc4 = 10

OC4REF rising or falling edges generate pulses on TRGO2



ComparePulseOc6 = 11

OC6REF rising or falling edges generate pulses on TRGO2



ComparePulseOc4OrOc6Rising = 12

OC4REF or OC6REF rising edges generate pulses on TRGO2



ComparePulseOc4RisingOrOc6Falling = 13

OC4REF rising or OC6REF falling edges generate pulses on TRGO2



ComparePulseOc5OrOc6Rising = 14

OC5REF or OC6REF rising edges generate pulses on TRGO2



ComparePulseOc5RisingOrOc6Falling = 15

OC5REF rising or OC6REF falling edges generate pulses on TRGO2

Implementations



impl Mms2

pub const fn from_bits(val: u8) -> Mms2

pub const fn to_bits(self) -> u8